 /*
    * Copyright (c) 2012, H. J. Ohlbach. All rights reserved.
    * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
    *
    * This code is free software; you can redistribute it and/or modify it
    * under the terms of the GNU General Public License version 2 only, as
    * published by the Free Software Foundation. 
    *
    * This code is distributed in the hope that it will be useful, but WITHOUT
    * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    * version 2 for more details.
    */
package Java2OWL;


import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.Map;
import org.apache.bcel.classfile.Attribute;
import org.apache.bcel.classfile.Visitor;
import org.apache.bcel.classfile.ConstantPool;

/** This class represents RuntimeVisibleAnnotations for the BCEL programs.
 *<p>It is adapted from an implementation by Don Schwarz.
 * 
 * <p> All RuntimeVisibleAnnotations are collected in an array of maps. 
 * 
 * Get the <a href="http://onjava.com/onjava/2004/06/30/examples/peekinginside-pt1.tar.gz">Original Code</a> here.
 * @author Don Schwarz 
 */
public class AnnotationsAttribute extends Attribute
{
    private static final String TYPE = "_type";
    private Map[] annotations;
    byte[] bytes;

    public AnnotationsAttribute (byte tag, int name_index, int length, ConstantPool constant_pool, 
            Map[] annotations, byte[] bytes){
            super(tag, name_index, length, constant_pool);
            this.annotations = annotations;
            this.bytes = bytes;}

    /** returns the annotations */
    public Map[] getAnnotations (){return annotations;}
        
    /** gets a particular annotation */ 
    public Map getAnnotation(String type) {
        for(Map m : annotations) if(m.get(TYPE).equals(type)) return m;
        return null;}

    @Override
    public void accept (Visitor v){throw new UnsupportedOperationException();}

    @Override
    public Attribute copy (ConstantPool cp){return this;}

    @Override
    public String toString (){return Arrays.toString(annotations);}
    	
    
    @Override
    public void dump (DataOutputStream out) throws IOException{
            super.dump(out);
            out.write(bytes, 0, bytes.length);}

}

