 /*
    * Copyright (c) 2012, H. J. Ohlbach. All rights reserved.
    * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
    *
    * This code is free software; you can redistribute it and/or modify it
    * under the terms of the GNU General Public License version 2 only, as
    * published by the Free Software Foundation. 
    *
    * This code is distributed in the hope that it will be useful, but WITHOUT
    * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    * version 2 for more details.
    */
package Java2OWL;

import java.lang.annotation.*;

/** This specifies the class-level annotations.
 *
 * @author ohlbach
 */
@Documented
@Retention(value=RetentionPolicy.RUNTIME)
@Target(value=ElementType.TYPE)
public @interface J2OWLClass {
    /** This provides the name of the to be generated OWL-class.  
     *  If it is empty then the OWL-class has the same name as the Java-class.  
     */
    String name() default "";
    
    /** This is a comma-separated list of OWL class names (from the background ontology).
     * The generated OWL-class is made a subclass of the given OWL-classes.
     */
    String OWLSuperClasses() default ""; 
    
    /** This is an OWL class expression in Manchester syntax which causes the generated OWL class to be equivalent to the 
     * given class expression.
     */
    String EquivalentClass() default ""; 
    
    /** This controls the injection of synchronisation code. 
     * If it is set to false then no synchronisation code is inserted.
     */
    boolean synchronise() default true;
    
    /** This is the name of a String-valued getter-method. 
     * Its result is used as name for the generated OWL-individual.
     * If the attribute is the empty string then <OWL-classname>_<counter> is used as name. 
     */
    String naming() default "getName";
    
}
