/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package Java2OWL;

import TestPackage.TestVehicle.TestSurfaceVehicle;
import TestPackage.TestVehicle.TestShip;
import TestPackage.TestVehicle;
import org.semanticweb.owlapi.expression.ParserException;
import org.semanticweb.owlapi.model.OWLNamedIndividual;
import java.util.Set;
import org.semanticweb.owlapi.model.OWLOntology;
import org.semanticweb.owlapi.util.AutoIRIMapper;
import java.io.File;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/** This class is for testing the Multi-Inheritance facilities.
 * 
 * <p>compile TestPackage.TestVehicle.java first!
 *
 * @author ohlbach
 */
public class MultiInheritanceTest {
    static J2OManager manager;
    static J2OOntologyManager omg;
    static J2OClassManager clm;
    static J2OIndividualManager img;
    
    public MultiInheritanceTest() {
    }

    @BeforeClass
    public static void setUpClass() throws Exception {
        manager = new J2OManager("TestManager",J2OManager.Status.RUN,true);
        manager.getLogger().activateInfo(false);
   
        AutoIRIMapper  iriMapper = new AutoIRIMapper( new File("test/TestPackage"),true);
        omg = manager.getOntologyManager();
        omg.addIRIMapper(iriMapper);
        
        clm = manager.getClassManager();
        String name = "test/TestPackage/AmphibiousVehicle.owl";
        OWLOntology extOntology = omg.loadExtensionOntology(name);
        
        
        J2OCompiler comp = manager.getCompiler();
        comp.class2OWL(TestVehicle.class);
        comp.finishTranslation();  
         
        img = manager.getIndvidualManager();
        
        
    }

    @AfterClass
    public static void tearDownClass() throws Exception {
    }
    
    @Before
    public void setUp() {
    }
    
    @After
    public void tearDown() {
    }

    /**
     * Test of apply method, of class Function.
     * @throws ParserException 
     */
    @Test
    public void testIndividual2Java() throws ParserException {

        System.out.println("individual2Java");
        Set<OWLNamedIndividual> individuals = omg.getInstances("Ship");
        assertNotNull(individuals);
        assertTrue(individuals.size() > 0);
        OWLNamedIndividual QueenMary = individuals.iterator().next();
        
        IndividualWrapper qm = img.individual2Java(QueenMary);
        assertNotNull(qm);
        TestShip ship = (TestShip)qm.getObject(TestShip.class);
        assertEquals("Queen Mary",ship.getName());
        assertEquals(40.0,ship.getKnots(),0.0);
        assertEquals(2,ship.getOwners().size());
        assertEquals("[QueenElizabeth, PrinceCharles]",ship.getOwners().toString());
        
        TestVehicle[] predecessors = ship.getPredecessors();
        assertNotNull(predecessors);
        assertEquals(2,predecessors.length);
        TestVehicle pd1 = predecessors[0];
        assertEquals("King George",pd1.getName());
        assertEquals("TestSurfaceVehicle",pd1.getClass().getSimpleName());
        TestVehicle pd2 = predecessors[1];
        assertEquals("Queen Victoria",pd2.getName());
        assertEquals("TestVehicle",pd2.getClass().getSimpleName());
        

        TestSurfaceVehicle surfaceVehicle = (TestSurfaceVehicle)qm.getObject(TestSurfaceVehicle.class);
        assertEquals("Queen Mary",surfaceVehicle.getName());
        assertEquals(200,surfaceVehicle.getEnginePower(),0.0);
        assertEquals("[QueenElizabeth, PrinceCharles]",surfaceVehicle.getOwners().toString());
        predecessors = surfaceVehicle.getPredecessors();
        assertNotNull(predecessors);
        assertEquals(2,predecessors.length);
        assertTrue(pd1 == predecessors[0]);
        
        assertTrue(ship.getOwners() == surfaceVehicle.getOwners());
        assertTrue(ship.getName() == surfaceVehicle.getName());
        
        assertTrue(ship.getPredecessors() == surfaceVehicle.getPredecessors());
        
    }

   
    
}
